==> nodeinfo-0.3.0.tar.gz: nodeinfo-go/extension/mastodon.go <==
package extension

import (
	"encoding/json"
	"fmt"
	"io"
	"net/http"

	"codeberg.org/thefederationinfo/nodeinfo-go"
	known_extension "codeberg.org/thefederationinfo/nodeinfo_extension"
)

func init() {
	nodeinfo.RegisterExtension(&mastodon{})
}

type mastodon struct{}

func (mastodon) Name() string {
	return "mastodon"
}

type mastodonInstance struct {
	Title       string `json:"title"`
	Description string `json:"description"`
	Contact     struct {
		Email   string `json:"email"`
		Account struct {
			Username    string `json:"username"`
			DisplayName string `json:"display_name"`
		} `json:"account"`
	} `json:"contact"`
}

func (mastodon) Extend(c *http.Client, domain string, n *nodeinfo.Node) error {
	if n.Metadata == nil {
		n.Metadata = make(map[string]interface{})
	}

	name, _ := n.Metadata[known_extension.KeyName].(string)
	description, _ := n.Metadata[known_extension.KeyDescription].(string)
	_, adminsOK := n.Metadata[known_extension.KeyAdmins]

	if name == "" || description == "" || !adminsOK {
		resp, err := c.Get(fmt.Sprintf("https://%s/api/v2/instance", domain))
		if err != nil {
			return fmt.Errorf("could not query mastodon specific instance endpoint: %w", err)
		}
		rawResp, err := io.ReadAll(resp.Body)
		if err != nil {
			return err
		}

		mi := &mastodonInstance{}
		if err := json.Unmarshal(rawResp, mi); err != nil {
			return err
		}

		if name == "" {
			n.Metadata[known_extension.KeyName] = mi.Title
		}
		if description == "" {
			n.Metadata[known_extension.KeyDescription] = mi.Description
		}
		if !adminsOK {
			n.Metadata[known_extension.KeyAdmins] = []known_extension.NodeAdmin{{
				Name:    mi.Contact.Account.DisplayName,
				Account: mi.Contact.Account.Username,
				Email:   mi.Contact.Email,
			}}
		}
	}

	return nil
}

==> nodeinfo-0.3.1.tar.gz: nodeinfo-go/extension/mastodon.go <==
package extension

import (
	"encoding/json"
	"fmt"
	"io"
	"net/http"

	"codeberg.org/thefederationinfo/nodeinfo-go"
	known_extension "codeberg.org/thefederationinfo/nodeinfo_metadata_survey"
)

func init() {
	nodeinfo.RegisterExtension(&mastodon{})
}

type mastodon struct{}

func (mastodon) Name() string {
	return "mastodon"
}

type mastodonInstance struct {
	Title       string `json:"title"`
	Description string `json:"description"`
	Contact     struct {
		Email   string `json:"email"`
		Account struct {
			Username    string `json:"username"`
			DisplayName string `json:"display_name"`
		} `json:"account"`
	} `json:"contact"`
}

func (mastodon) Extend(c *http.Client, domain string, n *nodeinfo.Node) error {
	if n.Metadata == nil {
		n.Metadata = make(map[string]interface{})
	}

	name, _ := n.Metadata[known_extension.KeyName].(string)
	description, _ := n.Metadata[known_extension.KeyDescription].(string)
	_, adminsOK := n.Metadata[known_extension.KeyAdmins]

	if name == "" || description == "" || !adminsOK {
		resp, err := c.Get(fmt.Sprintf("https://%s/api/v2/instance", domain))
		if err != nil {
			return fmt.Errorf("could not query mastodon specific instance endpoint: %w", err)
		}
		rawResp, err := io.ReadAll(resp.Body)
		if err != nil {
			return err
		}

		mi := &mastodonInstance{}
		if err := json.Unmarshal(rawResp, mi); err != nil {
			return err
		}

		if name == "" {
			n.Metadata[known_extension.KeyName] = mi.Title
		}
		if description == "" {
			n.Metadata[known_extension.KeyDescription] = mi.Description
		}
		if !adminsOK {
			n.Metadata[known_extension.KeyAdmins] = []known_extension.NodeAdmin{{
				Name:    mi.Contact.Account.DisplayName,
				Account: mi.Contact.Account.Username,
				Email:   mi.Contact.Email,
			}}
		}
	}

	return nil
}
